searchNodes=[{"ref":"Ratio.html","title":"Ratio","type":"module","doc":"This module allows you to use Rational numbers in Elixir, to enable exact calculations with all numbers big and small. It also defines the new &lt;|&gt; operator and (optionally) overrides the arithmetic +, -, * and / operators to work with ints, floats and Rational numbers all alike. Floats are also automatically coerced into Rationals whenever possible. And don&#39;t worry: If you don&#39;t like operator-overloading: There are longhand function aliases available too. To use the module, use use Ratio where you need it. If you do not want to override the Kernel&#39;s built-in math operators, use # Does not override *, /, -, +, div, abs use Ratio, override_math: false If you just do not want to override the Kernel&#39;s built-in inline math operators, use use Ratio, inline_math: false # Does not override *, /, -, + use Ratio, inline_math: false If you do not want the new operator &lt;|&gt; to be imported, use # Does not include &lt;|&gt;, construct Rational numbers using Ratio.new(a, b) use Ratio, operator: false These options can be combined (with override_math taking precedence over inline_math )"},{"ref":"Ratio.html#*/2","title":"Ratio.*/2","type":"function","doc":"Multiplies two numbers. (one or both of which might be integers, floats or rationals) Examples iex&gt; ((2 &lt;|&gt; 3) * 10) 20 &lt;|&gt; 3 iex&gt; ( 1 &lt;|&gt; 3) * (1 &lt;|&gt; 2) 1 &lt;|&gt; 6"},{"ref":"Ratio.html#+/1","title":"Ratio.+/1","type":"function","doc":"Unary plus. Returns num. Coerces the number to a rational if it is a float."},{"ref":"Ratio.html#+/2","title":"Ratio.+/2","type":"function","doc":"Adds two numbers, one or both of which might be integers, floats or rationals. The result is converted to a rational if applicable. Examples iex&gt; 2 + 3 5 iex&gt; 2.3 + 0.3 13 &lt;|&gt; 5 iex&gt; 2 + (2 &lt;|&gt; 3) 8 &lt;|&gt; 3"},{"ref":"Ratio.html#-/1","title":"Ratio.-/1","type":"function","doc":"Unary minus. Inverts the sign of the given num, which might be an integer, float or rational. Floats are converted to Rationals before inverting the sign. Examples iex&gt; -10 -10 iex&gt; -10.0 -10 iex&gt; -10.1 -101 &lt;|&gt; 10 iex&gt; -(5 &lt;|&gt; 3) -5 &lt;|&gt; 3 iex&gt; -123.456 -15432 &lt;|&gt; 125"},{"ref":"Ratio.html#-/2","title":"Ratio.-/2","type":"function","doc":"Subtracts b from a. One or both might be integers, floats or rationals. The result is converted to a rational if applicable. Examples iex&gt; 2 - 3 -1 iex&gt; 2.3 - 0.3 2 iex&gt; 2.3 - 0.1 11 &lt;|&gt; 5 iex&gt; (2 &lt;|&gt; 3) - (1 &lt;|&gt; 5) 7 &lt;|&gt; 15"},{"ref":"Ratio.html#//2","title":"Ratio.//2","type":"function","doc":"Divides a number by another number, one or both of which might be integers, floats or rationals. The function will return integers whenever possible, and otherwise returns a rational number. Examples iex&gt; (1 &lt;|&gt; 3) / 2 1 &lt;|&gt; 6 iex&gt; (2 &lt;|&gt; 3) / (8 &lt;|&gt; 5) 5 &lt;|&gt; 12 iex&gt; 2.0 / 1.0 2"},{"ref":"Ratio.html#</2","title":"Ratio.</2","type":"function","doc":"Compares two numbers and returns true if the first is less than the second. Examples iex&gt; 2 &lt; 3 true iex&gt; 5 &lt; 5 false iex&gt; 2.3 &lt; 0.3 false iex&gt; 10 &lt; (1 &lt;|&gt; 10) false"},{"ref":"Ratio.html#<=/2","title":"Ratio.<=/2","type":"function","doc":"Compares two numbers and returns true if the first is less than or equal to the second. Examples iex&gt; 2 &lt;= 3 true iex&gt; 5 &lt;= 5 true iex&gt; 2.3 &lt;= 0.3 false iex&gt; 10 &lt;= (1 &lt;|&gt; 10) false"},{"ref":"Ratio.html#<|>/2","title":"Ratio.<|>/2","type":"function","doc":"Creates a new Rational number. This number is simplified to the most basic form automatically. If the most basic form has the format _ &lt;|&gt; 1, it is returned in integer form. Rational numbers with a 0 as denominator are not allowed. Note that it is recommended to use integer numbers for the numerator and the denominator. Floats Tl;Dr: If possible, don&#39;t use them. Using Floats for the numerator or denominator is possible, however, because base-2 floats cannot represent all base-10 fractions properly, the results might be different from what you might expect. See The Perils of Floating Point for more information about this. Passed floats are rounded to 10 digits, to make the result match expectations better. This number can be changed by adding max_float_to_rational_digits: 10 to your config file. See Ratio.FloatConversion.float_to_rational/2 for more info about float -&gt; rational parsing. As Float-parsing is done by converting floats to a digit-list representation first, this is also far slower than when using integers or rationals. Examples iex&gt; 1 &lt;|&gt; 2 1 &lt;|&gt; 2 iex&gt; 100 &lt;|&gt; 300 1 &lt;|&gt; 3 iex&gt; 1.5 &lt;|&gt; 4 3 &lt;|&gt; 8"},{"ref":"Ratio.html#==/2","title":"Ratio.==/2","type":"function","doc":"Compares two numbers and returns true if the first equal to the second. Examples iex&gt; 2 == 3 false iex&gt; 5 == 5 true iex&gt; 2.3 == 0.3 false iex&gt; 0.1 == (1 &lt;|&gt; 10) true"},{"ref":"Ratio.html#>/2","title":"Ratio.>/2","type":"function","doc":"Compares two numbers and returns true if the first is greater than the second. Examples iex&gt; 2 &gt; 3 false iex&gt; 5 &gt; 5 false iex&gt; 2.3 &gt; 0.3 true iex&gt; 10 &gt; (1 &lt;|&gt; 10) true"},{"ref":"Ratio.html#>=/2","title":"Ratio.>=/2","type":"function","doc":"Compares two numbers and returns true if the first is greater than or equal to the second. Examples iex&gt; 2 &gt;= 3 false iex&gt; 5 &gt;= 5 true iex&gt; 2.3 &gt;= 0.3 true iex&gt; 10 &gt;= (1 &lt;|&gt; 10) true"},{"ref":"Ratio.html#__struct__/0","title":"Ratio.__struct__/0","type":"function","doc":"A Rational number is defined as a numerator and a denominator. Both the numerator and the denominator are integers. If you want to match for a rational number, you can do so by matching against this Struct. Note that directly manipulating the struct, however, is usually a bad idea, as then there are no validity checks, nor wil the rational be simplified. Use Ratio.&lt;|&gt;/2 or Ratio.new/2 instead."},{"ref":"Ratio.html#abs/1","title":"Ratio.abs/1","type":"function","doc":"Returns the absolute version of the given number (which might be an integer, float or Rational). Examples iex&gt;Ratio.abs(-5 &lt;|&gt; 2) 5 &lt;|&gt; 2"},{"ref":"Ratio.html#add/2","title":"Ratio.add/2","type":"function","doc":"Longhand for Ratio.+/2"},{"ref":"Ratio.html#ceil/1","title":"Ratio.ceil/1","type":"function","doc":"Rounds a number (rational, integer or float) to the largest whole number larger than or equal to num. For negative numbers, this means we are rounding towards negative infinity. iex&gt; Ratio.ceil(Ratio.new(1, 2)) 1 iex&gt; Ratio.ceil(Ratio.new(5, 4)) 2 iex&gt; Ratio.ceil(Ratio.new(-3, 2)) -1"},{"ref":"Ratio.html#compare/2","title":"Ratio.compare/2","type":"function","doc":""},{"ref":"Ratio.html#denominator/1","title":"Ratio.denominator/1","type":"function","doc":"Treats the passed number as a Rational number, and extracts its denominator. For integers, returns 1."},{"ref":"Ratio.html#div/2","title":"Ratio.div/2","type":"function","doc":"Longhand for Ratio.//2"},{"ref":"Ratio.html#eq?/2","title":"Ratio.eq?/2","type":"function","doc":"True if a is equal to b"},{"ref":"Ratio.html#equal?/2","title":"Ratio.equal?/2","type":"function","doc":"True if a is equal to b?"},{"ref":"Ratio.html#floor/1","title":"Ratio.floor/1","type":"function","doc":"Rounds a number (rational, integer or float) to the largest whole number less than or equal to num. For negative numbers, this means we are rounding towards negative infinity. iex&gt; Ratio.floor(Ratio.new(1, 2)) 0 iex&gt; Ratio.floor(Ratio.new(5, 4)) 1 iex&gt; Ratio.floor(Ratio.new(-3, 2)) -2"},{"ref":"Ratio.html#gt?/2","title":"Ratio.gt?/2","type":"function","doc":"True if a is larger than or equal to b"},{"ref":"Ratio.html#gte?/2","title":"Ratio.gte?/2","type":"function","doc":"True if a is larger than or equal to b"},{"ref":"Ratio.html#is_rational?/1","title":"Ratio.is_rational?/1","type":"function","doc":"Check if a number is a rational number. Returns false if the number is an integer, float or any other type. To check if a float representation will result in a rational number, combine it with the unary plus operation: Examples iex&gt;Ratio.is_rational?(10) false iex&gt;Ratio.is_rational?(&quot;foo&quot;) false iex&gt;Ratio.is_rational?(10.0) false iex&gt;Ratio.is_rational?(10.234) false iex&gt;Ratio.is_rational?(10 &lt;|&gt; 3) true iex&gt;Ratio.is_rational?(10 &lt;|&gt; 5) false iex&gt;Ratio.is_rational?(+20.234) true iex&gt;Ratio.is_rational?(+20.0) false"},{"ref":"Ratio.html#lt?/2","title":"Ratio.lt?/2","type":"function","doc":"True if a is smaller than b"},{"ref":"Ratio.html#lte?/2","title":"Ratio.lte?/2","type":"function","doc":"True if a is smaller than or equal to b"},{"ref":"Ratio.html#minus/1","title":"Ratio.minus/1","type":"function","doc":"Alias for Ratio.negate(num); follows Numeric behaviour."},{"ref":"Ratio.html#mult/2","title":"Ratio.mult/2","type":"function","doc":"Longhand for Ratio.*/2"},{"ref":"Ratio.html#negate/1","title":"Ratio.negate/1","type":"function","doc":"Longhand for Ratio.-/1"},{"ref":"Ratio.html#new/2","title":"Ratio.new/2","type":"function","doc":"Prefix-version of numerator &lt;|&gt; denominator. Useful when &lt;|&gt; is not available (for instance, when already in use by another module) Not imported when calling use Ratio, so always call it as Ratio.new(a, b) Examples iex&gt; Ratio.new(1, 2) 1 &lt;|&gt; 2 iex&gt; Ratio.new(100, 300) 1 &lt;|&gt; 3 iex&gt; Ratio.new(1.5, 4) 3 &lt;|&gt; 8"},{"ref":"Ratio.html#numerator/1","title":"Ratio.numerator/1","type":"function","doc":"Converts the passed number as a Rational number, and extracts its denominator. For integers returns the passed number itself."},{"ref":"Ratio.html#pow/2","title":"Ratio.pow/2","type":"function","doc":"returns x to the n th power. x is allowed to be an integer, rational or float (in the last case, this is first converted to a rational). Will give the answer as a rational number when applicable. Note that the exponent n is only allowed to be an integer. (so it is not possible to compute roots using this function.) Examples iex&gt;pow(2, 4) 16 iex&gt;pow(2, -4) 1 &lt;|&gt; 16 iex&gt;pow(3 &lt;|&gt; 2, 10) 59049 &lt;|&gt; 1024"},{"ref":"Ratio.html#sign/1","title":"Ratio.sign/1","type":"function","doc":"Returns the sign of the given number (which might be an integer, float or Rational) This is: 1 if the number is positive. -1 if the number is negative. 0 if the number is zero."},{"ref":"Ratio.html#sub/2","title":"Ratio.sub/2","type":"function","doc":"Longhand for Ratio.-/2"},{"ref":"Ratio.html#to_float/1","title":"Ratio.to_float/1","type":"function","doc":"Converts the given number to a Float. As floats do not have arbitrary precision, this operation is generally not reversible. Not imported when calling use Ratio, so always call it as Rational.to_float(number)"},{"ref":"Ratio.html#to_float_error/1","title":"Ratio.to_float_error/1","type":"function","doc":"Returns a tuple, where the first element is the result of to_float(number) and the second is a conversion error. The conversion error is calculated by subtracting the original number from the conversion result. Examples iex&gt; Ratio.to_float_error(Ratio.new(1, 2)) {0.5, 0} iex&gt; Ratio.to_float_error(Ratio.new(2, 3)) {0.6666666666666666, 1 &lt;|&gt; 30000000000}"},{"ref":"Ratio.html#to_string/1","title":"Ratio.to_string/1","type":"function","doc":"Returns a binstring representation of the Rational number. If the denominator is 1, it will be printed as a normal (integer) number. Examples iex&gt; Ratio.to_string 10 &lt;|&gt; 7 &quot;10 &lt;|&gt; 7&quot;"},{"ref":"Ratio.html#trunc/1","title":"Ratio.trunc/1","type":"function","doc":"Returns the integer part of number. Examples iex&gt; Ratio.trunc(1.7) 1 iex&gt; Ratio.trunc(-1.7) -1 iex&gt; Ratio.trunc(3) 3 iex&gt; Ratio.trunc(Ratio.new(5, 2)) 2"},{"ref":"Ratio.html#t:t/0","title":"Ratio.t/0","type":"type","doc":""},{"ref":"Ratio.ComparisonError.html","title":"Ratio.ComparisonError","type":"exception","doc":""},{"ref":"Ratio.FloatConversion.html","title":"Ratio.FloatConversion","type":"module","doc":""},{"ref":"Ratio.FloatConversion.html#float_to_rational/2","title":"Ratio.FloatConversion.float_to_rational/2","type":"function","doc":"Converts a float to a rational number. Because base-2 floats cannot represent all base-10 fractions properly, the results might be different from what you might expect. See The Perils of Floating Point for more information about this. It is possible to restrict max_decimals to make the result more readable/understandable, at the possible loss of precision. The default value for max_decimals is 10 (Erlang allows values between 0 and 249, see erlang&#39;s float_to_list function) Examples iex&gt; Ratio.FloatConversion.float_to_rational(10.0) 10 iex&gt; Ratio.FloatConversion.float_to_rational(13.5) 27 &lt;|&gt; 2 iex&gt; Ratio.FloatConversion.float_to_rational(1.1, 100) 2476979795053773 &lt;|&gt; 2251799813685248 iex&gt; Ratio.FloatConversion.float_to_rational(1.1, 3) 11 &lt;|&gt; 10"}]